@@ -9,16 +9,17 @@ compas_ghpython
     :maxdepth: 1
 
     compas_ghpython.artists
-    compas_ghpython.geometry
-    compas_ghpython.helpers
     compas_ghpython.utilities
 
 """
-from .utilities import *  # noqa: F401 F403
-from .helpers import *  # noqa: F401 F403
+import compas
+
+if compas.RHINO:
+    from .utilities import *  # noqa: F401 F403
 
 
-__version__ = '0.15.6'
+__version__ = '0.16.3'
 
 
-__all__ = []
+__all_plugins__ = ['compas_ghpython.install']
+__all__ = [name for name in dir() if not name.startswith('_')]
