@@ -18,22 +18,24 @@ compas_rhino
 """
 from __future__ import absolute_import
 
+import io
 import os
+
 import compas
 import compas._os
-from .utilities import *  # noqa: F401 F403
 
 if compas.RHINO:
     import rhinoscriptsyntax as rs  # noqa: F401
-    import scriptcontext as sc  # noqa: F401
-    find_object = sc.doc.Objects.Find
+    from .utilities import *  # noqa: F401 F403
 
 
-__version__ = '0.16.2'
+__version__ = '0.16.3'
 
 
 PURGE_ON_DELETE = True
 
+INSTALLABLE_PACKAGES = ['compas', 'compas_rhino', 'compas_ghpython']
+
 
 def _check_rhino_version(version):
     supported_versions = ['5.0', '6.0', '7.0']
@@ -98,18 +100,18 @@ def _get_python_plugins_path(version):
 
 
 def _get_python_plugins_path_win32(version):
-    appdata = os.getenv('APPDATA')
-    return os.path.join(appdata,
-                        'McNeel',
-                        'Rhinoceros',
-                        '{}'.format(version),
-                        'Plug-ins',
-                        'PythonPlugins')
+    return os.path.join(
+        os.getenv('APPDATA'),
+        'McNeel',
+        'Rhinoceros',
+        '{}'.format(version),
+        'Plug-ins',
+        'PythonPlugins')
 
 
 def _get_python_plugins_path_mac(version):
     if version == '5.0':
-        path = os.path.join(
+        return os.path.join(
             os.environ['HOME'],
             'Library',
             'Application Support',
@@ -117,18 +119,85 @@ def _get_python_plugins_path_mac(version):
             'Rhinoceros',
             'MacPlugIns',
             'PythonPlugIns')
+
+    return os.path.join(
+        os.environ['HOME'],
+        'Library',
+        'Application Support',
+        'McNeel',
+        'Rhinoceros',
+        '{}'.format(version),
+        'Plug-ins',
+        'PythonPlugIns')
+
+
+def _get_scripts_path(version):
+    version = _check_rhino_version(version)
+
+    if compas._os.system == 'win32':
+        scripts_path = _get_scripts_path_win32(version)
+    elif compas._os.system == 'darwin':
+        scripts_path = _get_scripts_path_mac(version)
     else:
-        path = os.path.join(
-            os.environ['HOME'],
-            'Library',
-            'Application Support',
-            'McNeel',
-            'Rhinoceros',
-            '{}'.format(version),
-            'Plug-ins',
-            'PythonPlugIns')
-    return path
+        raise Exception('Unsupported platform')
+
+    if not os.path.exists(scripts_path):
+        raise Exception("The folder for RhinoPython scripts does not exist in this location: {}".format(scripts_path))
+
+    return scripts_path
+
+
+def _get_scripts_path_win32(version):
+    return os.path.join(
+        os.getenv('APPDATA'), 'McNeel', 'Rhinoceros', '{}'.format(version), 'scripts')
+
+
+def _get_scripts_path_mac(version):
+    return os.path.join(
+        os.getenv('HOME'), 'Library', 'Application Support', 'McNeel', 'Rhinoceros', '{}'.format(version), 'scripts')
+
+
+def _get_package_path(package):
+    return os.path.abspath(os.path.dirname(package.__file__))
+
+
+def _get_bootstrapper_path(install_path):
+    return os.path.join(install_path, 'compas_bootstrapper.py')
+
+
+def _get_bootstrapper_data(compas_bootstrapper):
+    data = {}
+
+    if not os.path.exists(compas_bootstrapper):
+        return data
+
+    content = io.open(compas_bootstrapper, encoding='utf8').read()
+    exec(content, data)
+
+    return data
+
+
+def _try_remove_bootstrapper(path):
+    """Try to remove bootstrapper.
+
+    Returns
+    -------
+    bool: ``True`` if the operation did not cause errors, ``False`` otherwise.
+    """
+
+    bootstrapper = _get_bootstrapper_path(path)
+
+    if os.path.exists(bootstrapper):
+        try:
+            os.remove(bootstrapper)
+            return True
+        except:  # noqa: E722
+            return False
+    return True
 
 
-__all_plugins__ = ['compas_rhino.geometry.booleans']
 __all__ = [name for name in dir() if not name.startswith('_')]
+__all_plugins__ = [
+    'compas_rhino.geometry.booleans',
+    'compas_rhino.install',
+]
